require 'faraday'
require 'json'

module PusherNotification
  VERSION = '0.22'.freeze

  class << self
    INTERESTS_MAX_LENGTH = 164

    attr_accessor :config

    def publish(payload = {})
      validate_payload(payload)

      Faraday.post(
        base_url + path,
        payload.to_json,
        {
          'Content-Type'  => 'application/json',
          'Authorization' => "Bearer #{config[:secret_key]}"
        }
      )
    end

    private

    def validate_payload(payload = {})
      unless config.key?(:instance_id) && config.key?(:secret_key)
        raise 'Config must be provided before publishing'
      end

      unless payload.key?(:interests)
        raise 'Interests is a required parameter.'
      end

      if payload[:interests].any? {|interest| interest.length > INTERESTS_MAX_LENGTH }
        raise "Interests can not be longer than the maximum of #{INTERESTS_MAX_LENGTH}."
      end
    end

    def base_url
      "https://#{config[:instance_id]}.pushnotifications.pusher.com"
    end

    def path
      "/publish_api/v1/instances/#{config[:instance_id]}/publishes"
    end
  end
end
